@@ -1,20 +1,23 @@
-import os
-import time
-from uuid import uuid4
+import cPickle
+import hashlib
 import inspect
 import logging
 import logging.handlers
+import os
+import time
+from uuid import uuid4
 from twisted.internet import reactor
 from twisted.internet.defer import Deferred, DeferredList, maybeDeferred
 from ..aws import AmazonS3, AmazonSDB
-from ..requestqueuer import RequestQueuer
-from ..pagegetter import PageGetter
-from ..timeoffset import getTimeOffset
 from ..exceptions import DeleteReservationException
-import cPickle
+from ..pagegetter import PageGetter
+from ..requestqueuer import RequestQueuer
+from ..timeoffset import getTimeOffset
+
 
 LOGGER = logging.getLogger("main")
 
+
 class BaseServer(object):
     
     logging_handler = None
@@ -32,7 +35,7 @@ class BaseServer(object):
     def __init__(self,
                  aws_access_key_id, 
                  aws_secret_access_key, 
-                 aws_s3_cache_bucket=None, 
+                 aws_s3_http_cache_bucket=None, 
                  aws_sdb_reservation_domain=None, 
                  aws_s3_storage_bucket=None,
                  aws_sdb_coordination_domain=None,
@@ -59,13 +62,22 @@ class BaseServer(object):
         self.rq.setHostMaxSimultaneousRequests("127.0.0.1", 0)
         self.aws_access_key_id = aws_access_key_id
         self.aws_secret_access_key = aws_secret_access_key
-        self.aws_s3_cache_bucket = aws_s3_cache_bucket
+        self.aws_s3_http_cache_bucket = aws_s3_http_cache_bucket
         self.aws_s3_storage_bucket = aws_s3_storage_bucket
         self.aws_sdb_reservation_domain = aws_sdb_reservation_domain
         self.aws_sdb_coordination_domain = aws_sdb_coordination_domain
-        self.s3 = AmazonS3(self.aws_access_key_id, self.aws_secret_access_key, self.rq)
-        self.sdb = AmazonSDB(self.aws_access_key_id, self.aws_secret_access_key, self.rq)
-        self.pg = PageGetter(self.s3, self.aws_s3_cache_bucket, rq=self.rq)
+        self.s3 = AmazonS3(
+            self.aws_access_key_id, 
+            self.aws_secret_access_key, 
+            rq=self.rq)
+        self.sdb = AmazonSDB(
+            self.aws_access_key_id, 
+            self.aws_secret_access_key, 
+            rq=self.rq)
+        self.pg = PageGetter(
+            self.s3, 
+            self.aws_s3_http_cache_bucket, 
+            rq=self.rq)
         self._setupLogging(log_file, log_directory, log_level)
         if self.name is not None:
             LOGGER.info("Successfully loaded %s configuration." % self.name)
@@ -104,9 +116,9 @@ class BaseServer(object):
     def _baseStart(self):
         LOGGER.critical("Checking S3 and SDB setup.")
         deferreds = []
-        if self.aws_s3_cache_bucket is not None:
+        if self.aws_s3_http_cache_bucket is not None:
             deferreds.append(
-                self.s3.checkAndCreateBucket(self.aws_s3_cache_bucket))   
+                self.s3.checkAndCreateBucket(self.aws_s3_http_cache_bucket))
         if self.aws_sdb_reservation_domain is not None:
             deferreds.append(
                 self.sdb.checkAndCreateDomain(self.aws_sdb_reservation_domain))
@@ -304,4 +316,30 @@ class BaseServer(object):
     def _deleteReservationErrback(self, error, function_name, uuid ):
         LOGGER.error("Error deleting reservation %s, %s.\n%s" % (function_name, uuid, error))
         return False
+    
+    def deleteHTTPCache(self):
+        deferreds = []
+        if self.aws_s3_http_cache_bucket is not None:
+            deferreds.append(
+                self.s3.emptyBucket(self.aws_s3_http_cache_bucket))
+        if len(deferreds) > 0:
+            d = DeferredList(deferreds, consumeErrors=True)
+            d.addCallback(self._deleteHTTPCacheCallback)
+            return d
+        else:
+            return True
         
+    def _deleteHTTPCacheCallback(self, data):
+        deferreds = []
+        if self.aws_s3_http_cache_bucket is not None:
+            deferreds.append(
+                self.s3.deleteBucket(self.aws_s3_http_cache_bucket))
+        if len(deferreds) > 0:
+            d = DeferredList(deferreds, consumeErrors=True)
+            d.addCallback(self._deleteHTTPCacheCallback2)
+            return d
+        else:
+            return True
+            
+    def _deleteHTTPCacheCallback2(self, data):
+        return True
